@@ -1,6 +1,9 @@
 from django.forms import Form
 from django.template.loader import render_to_string
-from pml.forms.fields import PMLCheckBoxField, PMLRadioField, PMLSelectField, PMLTextField
+from pml.forms.fields import (
+    PMLCheckBoxField, PMLRadioField, PMLSelectField,
+    PMLTextField, PMLHiddenField
+)
 
 
 class PMLForm(Form):
